Example notebooks
=================

These examples are also available on `GitHub <https://github
.com/py-why/dowhy/tree/master/docs/source/example_notebooks>`_. You can `run them locally <https://docs.jupyter
.org/en/latest/running.html>`_ after cloning `DoWhy <https://github.com/py-why/dowhy>`_ and `installing Jupyter
<https://jupyter.org/install>`_. Or you can run them directly in a web browser using the
`Binder environment <https://mybinder.org/v2/gh/microsoft/dowhy/master?filepath=docs%2Fsource%2F>`_. 


.. toctree::
   :maxdepth: 1
   :caption: Getting started
   
   dowhy_simple_example
   dowhy_confounder_example
   dowhy_estimation_methods
   graph_conditional_independence_refuter
   dowhy-simple-iv-example
   load_graph_example
   dowhy_interpreter
   dowhy_causal_discovery_example
   dowhy_causal_api
   do_sampler_demo
   gcm_basic_example

.. toctree::
   :maxdepth: 1
   :caption: Using benchmark datasets
   
   dowhy_ihdp_data_example
   dowhy_twins_example
   dowhy_lalonde_example
   dowhy_refutation_testing
   lalonde_pandas_api

.. Advanced notebooks
   
.. toctree::
   :maxdepth: 1
   :caption: Advanced

   dowhy-conditional-treatment-effects
   dowhy_mediation_analysis.ipynb
   dowhy_demo_dummy_outcome_refuter.ipynb
   dowhy_multiple_treatments.ipynb
   dowhy_refuter_notebook
   dowhy_causal_discovery_example.ipynb
   identifying_effects_using_id_algorithm.ipynb
   rca_microservice_architecture
   gcm_supply_chain_dist_change
   gcm-counterfactual-example
   gcm_401k_analysis
